searchData={"items":[{"type":"module","title":"ExDicom","doc":"Main module for DICOM file parsing functionality.","ref":"ExDicom.html"},{"type":"function","title":"ExDicom.parse_file/1","doc":"Parses a DICOM file from the given file path.","ref":"ExDicom.html#parse_file/1"},{"type":"function","title":"Parameters - ExDicom.parse_file/1","doc":"* file_path - Path to the DICOM file to parse","ref":"ExDicom.html#parse_file/1-parameters"},{"type":"function","title":"Returns - ExDicom.parse_file/1","doc":"* `{:ok, dataset}` - Successfully parsed DICOM data\n  * `{:error, reason}` - Error occurred during parsing","ref":"ExDicom.html#parse_file/1-returns"},{"type":"function","title":"Examples - ExDicom.parse_file/1","doc":"iex> {:error, message} = ExDicom.parse_file(\"non_existent.dcm\")\n    iex> is_binary(message)\n    true","ref":"ExDicom.html#parse_file/1-examples"},{"type":"function","title":"ExDicom.write_file/2","doc":"Writes a DICOM dataset to a file at the specified path.","ref":"ExDicom.html#write_file/2"},{"type":"function","title":"Parameters - ExDicom.write_file/2","doc":"* dataset - The DICOM dataset to write\n  * file_path - Path where the DICOM file should be written","ref":"ExDicom.html#write_file/2-parameters"},{"type":"function","title":"Returns - ExDicom.write_file/2","doc":"* `:ok` - Successfully wrote DICOM data\n  * `{:error, reason}` - Error occurred during writing","ref":"ExDicom.html#write_file/2-returns"},{"type":"function","title":"Examples - ExDicom.write_file/2","doc":"iex> {:ok, dataset} = ExDicom.parse_file(\"test/fixtures/brain.dcm\")\n      iex> path = \"test/fixtures/output.dcm\"\n      iex> result = ExDicom.write_file(dataset, path)\n      iex> File.rm!(path)\n      iex> result\n      :ok","ref":"ExDicom.html#write_file/2-examples"},{"type":"module","title":"ExDicom.Alloc","doc":"Module containing helper functions for working with binary data in DICOM parsing.","ref":"ExDicom.Alloc.html"},{"type":"function","title":"ExDicom.Alloc.zeros/1","doc":"Creates a new binary of the specified length filled with zeros.","ref":"ExDicom.Alloc.html#zeros/1"},{"type":"function","title":"Parameters - ExDicom.Alloc.zeros/1","doc":"* length - The desired length of the new binary in bytes","ref":"ExDicom.Alloc.html#zeros/1-parameters"},{"type":"function","title":"Returns - ExDicom.Alloc.zeros/1","doc":"* `{:ok, binary}` - A new zero-filled binary of the specified length\n  * `{:error, String.t()}` - Error message if the input is invalid","ref":"ExDicom.Alloc.html#zeros/1-returns"},{"type":"function","title":"Examples - ExDicom.Alloc.zeros/1","doc":"iex> ExDicom.Alloc.zeros(3)\n    {:ok, <<0, 0, 0>>}","ref":"ExDicom.Alloc.html#zeros/1-examples"},{"type":"module","title":"ExDicom.ByteAllocator","doc":"Provides functionality for allocating byte arrays (binaries) of specified lengths.","ref":"ExDicom.ByteAllocator.html"},{"type":"function","title":"ExDicom.ByteAllocator.alloc/2","doc":"Creates a new binary of the specified length.","ref":"ExDicom.ByteAllocator.html#alloc/2"},{"type":"function","title":"Parameters - ExDicom.ByteAllocator.alloc/2","doc":"* source - The source binary to determine the type\n  * length - The desired length of the new binary in bytes","ref":"ExDicom.ByteAllocator.html#alloc/2-parameters"},{"type":"function","title":"Returns - ExDicom.ByteAllocator.alloc/2","doc":"* `{:ok, binary}` - A new binary of the specified length filled with zeros\n  * `{:error, String.t()}` - Error message if the input type is not supported","ref":"ExDicom.ByteAllocator.html#alloc/2-returns"},{"type":"function","title":"Examples - ExDicom.ByteAllocator.alloc/2","doc":"iex> ByteAllocator.alloc(<<1, 2, 3>>, 5)\n    {:ok, <<0, 0, 0, 0, 0>>}\n\n    iex> ByteAllocator.alloc(\"not a binary\", 5)\n    {:error, \"unknown type for byte array\"}","ref":"ExDicom.ByteAllocator.html#alloc/2-examples"},{"type":"type","title":"ExDicom.ByteAllocator.byte_array/0","doc":"","ref":"ExDicom.ByteAllocator.html#t:byte_array/0"},{"type":"module","title":"ExDicom.ByteArrayParser","doc":"Internal helper functions common to parsing byte arrays of any type.","ref":"ExDicom.ByteArrayParser.html"},{"type":"function","title":"ExDicom.ByteArrayParser.read_fixed_string/3","doc":"Reads a string of 8-bit characters from a binary and returns the parsed string.\nA null terminator will end the string but will not affect the length parameter.\nTrailing and leading spaces are preserved (not trimmed).","ref":"ExDicom.ByteArrayParser.html#read_fixed_string/3"},{"type":"function","title":"Parameters - ExDicom.ByteArrayParser.read_fixed_string/3","doc":"* byte_array - The binary to read from\n  * position - The position in the binary to read from\n  * length - The maximum number of bytes to parse","ref":"ExDicom.ByteArrayParser.html#read_fixed_string/3-parameters"},{"type":"function","title":"Returns - ExDicom.ByteArrayParser.read_fixed_string/3","doc":"* `{:ok, string}` - The parsed string\n  * `{:error, string}` - Error message if reading fails","ref":"ExDicom.ByteArrayParser.html#read_fixed_string/3-returns"},{"type":"function","title":"Examples - ExDicom.ByteArrayParser.read_fixed_string/3","doc":"iex> ByteArrayParser.read_fixed_string(<<65, 66, 67, 0, 68>>, 0, 4)\n    {:ok, \"ABC\"}\n\n    iex> ByteArrayParser.read_fixed_string(<<65, 66, 67>>, 0, 5)\n    {:error, \"dicomParser.readFixedString: attempt to read past end of buffer\"}\n\n    iex> ByteArrayParser.read_fixed_string(<<32, 65, 66, 32>>, 0, 4)\n    {:ok, \" AB \"}","ref":"ExDicom.ByteArrayParser.html#read_fixed_string/3-examples"},{"type":"function","title":"ExDicom.ByteArrayParser.read_fixed_string!/3","doc":"Same as read_fixed_string/3 but raises on error.","ref":"ExDicom.ByteArrayParser.html#read_fixed_string!/3"},{"type":"function","title":"Examples - ExDicom.ByteArrayParser.read_fixed_string!/3","doc":"iex> ByteArrayParser.read_fixed_string!(<<65, 66, 67, 0, 68>>, 0, 4)\n    \"ABC\"\n\n    iex> ByteArrayParser.read_fixed_string!(<<65, 66, 67>>, 0, 5)\n    ** (RuntimeError) dicomParser.readFixedString: attempt to read past end of buffer","ref":"ExDicom.ByteArrayParser.html#read_fixed_string!/3-examples"},{"type":"function","title":"ExDicom.ByteArrayParser.read_fixed_string_fast/3","doc":"A more efficient version of read_fixed_string that operates directly on binaries\nwithout converting to lists. However, it will read the full length even after\nencountering a null terminator.\n\nThis is useful when you know your string won't contain null terminators\nor when you want to process the full binary segment regardless.","ref":"ExDicom.ByteArrayParser.html#read_fixed_string_fast/3"},{"type":"function","title":"Examples - ExDicom.ByteArrayParser.read_fixed_string_fast/3","doc":"iex> ByteArrayParser.read_fixed_string_fast(<<65, 66, 67, 68>>, 0, 4)\n    {:ok, \"ABCD\"}","ref":"ExDicom.ByteArrayParser.html#read_fixed_string_fast/3-examples"},{"type":"module","title":"ExDicom.ByteStream","doc":"Internal helper module to assist with parsing. Supports reading from a byte\nstream contained in a binary.\n\nExample usage:\n\n    byte_array = <<1, 2, 3, 4>>\n    {:ok, stream} = ByteStream.new(byte_array_parser, byte_array)","ref":"ExDicom.ByteStream.html"},{"type":"function","title":"ExDicom.ByteStream.add_warning/2","doc":"Adds a warning message to the ByteStream's warnings list.","ref":"ExDicom.ByteStream.html#add_warning/2"},{"type":"function","title":"Parameters - ExDicom.ByteStream.add_warning/2","doc":"* stream: ByteStream struct\n  * warning: warning message to add","ref":"ExDicom.ByteStream.html#add_warning/2-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.add_warning/2","doc":"* updated ByteStream struct with new warning added to warnings list","ref":"ExDicom.ByteStream.html#add_warning/2-returns"},{"type":"function","title":"ExDicom.ByteStream.get_position/1","doc":"Returns the current position in the byte array","ref":"ExDicom.ByteStream.html#get_position/1"},{"type":"function","title":"Parameters - ExDicom.ByteStream.get_position/1","doc":"* stream: ByteStream struct","ref":"ExDicom.ByteStream.html#get_position/1-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.get_position/1","doc":"* current position in bytes","ref":"ExDicom.ByteStream.html#get_position/1-returns"},{"type":"function","title":"ExDicom.ByteStream.get_size/1","doc":"Returns the size of the byte array","ref":"ExDicom.ByteStream.html#get_size/1"},{"type":"function","title":"Parameters - ExDicom.ByteStream.get_size/1","doc":"* stream: ByteStream struct","ref":"ExDicom.ByteStream.html#get_size/1-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.get_size/1","doc":"* size of the byte array in bytes","ref":"ExDicom.ByteStream.html#get_size/1-returns"},{"type":"function","title":"ExDicom.ByteStream.new/3","doc":"Creates a new ByteStream struct.","ref":"ExDicom.ByteStream.html#new/3"},{"type":"function","title":"Parameters - ExDicom.ByteStream.new/3","doc":"* byte_array_parser: module that implements parsing functions\n  * byte_array: binary containing the byte stream\n  * position: optional starting position (defaults to 0)","ref":"ExDicom.ByteStream.html#new/3-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.new/3","doc":"* `{:ok, stream}` if successful\n  * `{:error, reason}` if validation fails","ref":"ExDicom.ByteStream.html#new/3-returns"},{"type":"function","title":"ExDicom.ByteStream.read_byte_stream/2","doc":"Returns a new ByteStream struct from the current position containing the requested number of bytes","ref":"ExDicom.ByteStream.html#read_byte_stream/2"},{"type":"function","title":"Parameters - ExDicom.ByteStream.read_byte_stream/2","doc":"* stream: ByteStream struct\n  * num_bytes: length of the binary for the new ByteStream","ref":"ExDicom.ByteStream.html#read_byte_stream/2-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.read_byte_stream/2","doc":"* `{:ok, new_stream}` containing the requested bytes\n  * `{:error, reason}` if buffer overread would occur","ref":"ExDicom.ByteStream.html#read_byte_stream/2-returns"},{"type":"function","title":"ExDicom.ByteStream.read_fixed_string/2","doc":"Reads a string of 8-bit characters up to the specified length or null terminator","ref":"ExDicom.ByteStream.html#read_fixed_string/2"},{"type":"function","title":"Parameters - ExDicom.ByteStream.read_fixed_string/2","doc":"* stream: ByteStream struct\n  * length: maximum number of bytes to parse","ref":"ExDicom.ByteStream.html#read_fixed_string/2-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.read_fixed_string/2","doc":"* `{:ok, string, new_stream}` with parsed string and updated position\n  * `{:error, reason}` if buffer overread would occur","ref":"ExDicom.ByteStream.html#read_fixed_string/2-returns"},{"type":"function","title":"ExDicom.ByteStream.read_uint16/1","doc":"Parses an unsigned int 16 from the byte array and advances the position by 2 bytes","ref":"ExDicom.ByteStream.html#read_uint16/1"},{"type":"function","title":"Parameters - ExDicom.ByteStream.read_uint16/1","doc":"* stream: ByteStream struct","ref":"ExDicom.ByteStream.html#read_uint16/1-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.read_uint16/1","doc":"* `{:ok, value, new_stream}` with parsed uint16 and updated position\n  * `{:error, reason}` if buffer overread would occur","ref":"ExDicom.ByteStream.html#read_uint16/1-returns"},{"type":"function","title":"ExDicom.ByteStream.read_uint32/1","doc":"Parses an unsigned int 32 from the byte array and advances the position by 4 bytes","ref":"ExDicom.ByteStream.html#read_uint32/1"},{"type":"function","title":"Parameters - ExDicom.ByteStream.read_uint32/1","doc":"* stream: ByteStream struct","ref":"ExDicom.ByteStream.html#read_uint32/1-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.read_uint32/1","doc":"* `{:ok, value, new_stream}` with parsed uint32 and updated position\n  * `{:error, reason}` if buffer overread would occur","ref":"ExDicom.ByteStream.html#read_uint32/1-returns"},{"type":"function","title":"ExDicom.ByteStream.seek/2","doc":"Safely seeks through the byte stream. Returns error if attempt\nis made to seek outside of the byte array.","ref":"ExDicom.ByteStream.html#seek/2"},{"type":"function","title":"Parameters - ExDicom.ByteStream.seek/2","doc":"* stream: ByteStream struct\n  * offset: number of bytes to add to the position","ref":"ExDicom.ByteStream.html#seek/2-parameters"},{"type":"function","title":"Returns - ExDicom.ByteStream.seek/2","doc":"* `{:ok, new_stream}` with updated position\n  * `{:error, reason}` if seek would be invalid","ref":"ExDicom.ByteStream.html#seek/2-returns"},{"type":"type","title":"ExDicom.ByteStream.t/0","doc":"","ref":"ExDicom.ByteStream.html#t:t/0"},{"type":"module","title":"ExDicom.DataSet","doc":"Encapsulates a collection of DICOM Elements and provides various functions to access the data.\n\nRules for handling padded spaces:\n- DS = Strip leading and trailing spaces\n- DT = Strip trailing spaces\n- IS = Strip leading and trailing spaces\n- PN = Strip trailing spaces\n- TM = Strip trailing spaces\n- AE = Strip leading and trailing spaces\n- CS = Strip leading and trailing spaces\n- SH = Strip leading and trailing spaces\n- LO = Strip leading and trailing spaces\n- LT = Strip trailing spaces\n- ST = Strip trailing spaces\n- UT = Strip trailing spaces","ref":"ExDicom.DataSet.html"},{"type":"function","title":"ExDicom.DataSet.attribute_tag/2","doc":"Parses an element tag according to the 'AT' VR definition.","ref":"ExDicom.DataSet.html#attribute_tag/2"},{"type":"function","title":"ExDicom.DataSet.double/3","doc":"Finds the element for tag and returns a 64-bit float if it exists and has data.","ref":"ExDicom.DataSet.html#double/3"},{"type":"function","title":"ExDicom.DataSet.float/3","doc":"Finds the element for tag and returns a 32-bit float if it exists and has data.","ref":"ExDicom.DataSet.html#float/3"},{"type":"function","title":"ExDicom.DataSet.float_string/3","doc":"Parses a string to a float for the specified index in a multi-valued element.","ref":"ExDicom.DataSet.html#float_string/3"},{"type":"function","title":"ExDicom.DataSet.int16/3","doc":"Finds the element for tag and returns a signed int 16 if it exists and has data.","ref":"ExDicom.DataSet.html#int16/3"},{"type":"function","title":"ExDicom.DataSet.int32/3","doc":"Finds the element for tag and returns a signed int 32 if it exists and has data.","ref":"ExDicom.DataSet.html#int32/3"},{"type":"function","title":"ExDicom.DataSet.int_string/3","doc":"Parses a string to an integer for the specified index in a multi-valued element.","ref":"ExDicom.DataSet.html#int_string/3"},{"type":"function","title":"ExDicom.DataSet.new/3","doc":"Creates a new DicomDataset struct.","ref":"ExDicom.DataSet.html#new/3"},{"type":"function","title":"ExDicom.DataSet.num_string_values/2","doc":"Returns the number of string values for the element.","ref":"ExDicom.DataSet.html#num_string_values/2"},{"type":"function","title":"ExDicom.DataSet.string/3","doc":"Returns a string for the element. For VR types of AE, CS, SH and LO.\nIf index is provided, returns the component at that index in a multi-valued string.","ref":"ExDicom.DataSet.html#string/3"},{"type":"function","title":"ExDicom.DataSet.text/3","doc":"Returns a string with leading spaces preserved and trailing spaces removed.\nFor VRs of type UT, ST and LT.","ref":"ExDicom.DataSet.html#text/3"},{"type":"function","title":"ExDicom.DataSet.uint16/3","doc":"Finds the element for tag and returns an unsigned int 16 if it exists and has data.","ref":"ExDicom.DataSet.html#uint16/3"},{"type":"function","title":"ExDicom.DataSet.uint32/3","doc":"Finds the element for tag and returns an unsigned int 32 if it exists and has data.","ref":"ExDicom.DataSet.html#uint32/3"},{"type":"type","title":"ExDicom.DataSet.byte_array/0","doc":"","ref":"ExDicom.DataSet.html#t:byte_array/0"},{"type":"type","title":"ExDicom.DataSet.element/0","doc":"","ref":"ExDicom.DataSet.html#t:element/0"},{"type":"type","title":"ExDicom.DataSet.elements/0","doc":"","ref":"ExDicom.DataSet.html#t:elements/0"},{"type":"type","title":"ExDicom.DataSet.index/0","doc":"","ref":"ExDicom.DataSet.html#t:index/0"},{"type":"type","title":"ExDicom.DataSet.parser/0","doc":"","ref":"ExDicom.DataSet.html#t:parser/0"},{"type":"type","title":"ExDicom.DataSet.t/0","doc":"","ref":"ExDicom.DataSet.html#t:t/0"},{"type":"type","title":"ExDicom.DataSet.tag/0","doc":"","ref":"ExDicom.DataSet.html#t:tag/0"},{"type":"module","title":"ExDicom.Parser","doc":"Parses a DICOM P10 byte array and returns a DataSet object with the parsed elements.","ref":"ExDicom.Parser.html"},{"type":"function","title":"ExDicom.Parser.bei/0","doc":"","ref":"ExDicom.Parser.html#bei/0"},{"type":"function","title":"ExDicom.Parser.deflated/0","doc":"","ref":"ExDicom.Parser.html#deflated/0"},{"type":"function","title":"ExDicom.Parser.lee/0","doc":"","ref":"ExDicom.Parser.html#lee/0"},{"type":"function","title":"ExDicom.Parser.lei/0","doc":"","ref":"ExDicom.Parser.html#lei/0"},{"type":"function","title":"ExDicom.Parser.parse_dicom/2","doc":"Parses a DICOM P10 byte array and returns a DataSet object with the parsed elements.\nIf the options argument contains the :until_tag property, parsing will stop once\nthat tag is encountered.","ref":"ExDicom.Parser.html#parse_dicom/2"},{"type":"function","title":"Parameters - ExDicom.Parser.parse_dicom/2","doc":"* byte_array - The binary containing DICOM data\n  * opts - Options to control parsing behavior (optional)\n    * :until_tag - Stop parsing when this tag is encountered\n    * :inflater - Function to handle deflated transfer syntax","ref":"ExDicom.Parser.html#parse_dicom/2-parameters"},{"type":"function","title":"Returns - ExDicom.Parser.parse_dicom/2","doc":"* `{:ok, dataset}` - Successfully parsed DICOM data\n  * `{:error, reason}` - Error occurred during parsing","ref":"ExDicom.Parser.html#parse_dicom/2-returns"},{"type":"function","title":"Examples - ExDicom.Parser.parse_dicom/2","doc":"iex> Parser.parse_dicom(<<...>>)\n    {:ok, %DataSet{...}}","ref":"ExDicom.Parser.html#parse_dicom/2-examples"},{"type":"module","title":"ExDicom.Parser.BigEndianParser","doc":"Provides functions for parsing different numeric types from a big-endian binary.\nAll functions handle bounds checking and proper binary validation.","ref":"ExDicom.Parser.BigEndianParser.html"},{"type":"function","title":"ExDicom.Parser.BigEndianParser.read_double/2","doc":"Parses a 64-bit float from a big-endian binary.","ref":"ExDicom.Parser.BigEndianParser.html#read_double/2"},{"type":"function","title":"Parameters - ExDicom.Parser.BigEndianParser.read_double/2","doc":"* byte_array - The binary to parse from\n  * position - The position to start parsing from","ref":"ExDicom.Parser.BigEndianParser.html#read_double/2-parameters"},{"type":"function","title":"Returns - ExDicom.Parser.BigEndianParser.read_double/2","doc":"* `{:ok, float}` - The parsed 64-bit float\n  * `{:error, String.t()}` - Error message if parsing fails","ref":"ExDicom.Parser.BigEndianParser.html#read_double/2-returns"},{"type":"function","title":"Examples - ExDicom.Parser.BigEndianParser.read_double/2","doc":"iex> BigEndianParser.read_double(<<0x40, 0x09, 0x21, 0xFB, 0x54, 0x44, 0x2D, 0x18>>, 0)\n    {:ok, 3.14159}","ref":"ExDicom.Parser.BigEndianParser.html#read_double/2-examples"},{"type":"function","title":"ExDicom.Parser.BigEndianParser.read_float/2","doc":"Parses a 32-bit float from a big-endian binary.","ref":"ExDicom.Parser.BigEndianParser.html#read_float/2"},{"type":"function","title":"Parameters - ExDicom.Parser.BigEndianParser.read_float/2","doc":"* byte_array - The binary to parse from\n  * position - The position to start parsing from","ref":"ExDicom.Parser.BigEndianParser.html#read_float/2-parameters"},{"type":"function","title":"Returns - ExDicom.Parser.BigEndianParser.read_float/2","doc":"* `{:ok, float}` - The parsed 32-bit float\n  * `{:error, String.t()}` - Error message if parsing fails","ref":"ExDicom.Parser.BigEndianParser.html#read_float/2-returns"},{"type":"function","title":"Examples - ExDicom.Parser.BigEndianParser.read_float/2","doc":"iex> BigEndianParser.read_float(<<0x40, 0x48, 0xF5, 0xC3>>, 0)\n    {:ok, 3.14}","ref":"ExDicom.Parser.BigEndianParser.html#read_float/2-examples"},{"type":"function","title":"ExDicom.Parser.BigEndianParser.read_int16/2","doc":"Parses a signed 16-bit integer from a big-endian binary.","ref":"ExDicom.Parser.BigEndianParser.html#read_int16/2"},{"type":"function","title":"Parameters - ExDicom.Parser.BigEndianParser.read_int16/2","doc":"* byte_array - The binary to parse from\n  * position - The position to start parsing from","ref":"ExDicom.Parser.BigEndianParser.html#read_int16/2-parameters"},{"type":"function","title":"Returns - ExDicom.Parser.BigEndianParser.read_int16/2","doc":"* `{:ok, integer}` - The parsed signed 16-bit integer\n  * `{:error, String.t()}` - Error message if parsing fails","ref":"ExDicom.Parser.BigEndianParser.html#read_int16/2-returns"},{"type":"function","title":"Examples - ExDicom.Parser.BigEndianParser.read_int16/2","doc":"iex> BigEndianParser.read_int16(<<0xFF, 0xFE, 0x56>>, 0)\n    {:ok, -2}","ref":"ExDicom.Parser.BigEndianParser.html#read_int16/2-examples"},{"type":"function","title":"ExDicom.Parser.BigEndianParser.read_int32/2","doc":"Parses a signed 32-bit integer from a big-endian binary.","ref":"ExDicom.Parser.BigEndianParser.html#read_int32/2"},{"type":"function","title":"Parameters - ExDicom.Parser.BigEndianParser.read_int32/2","doc":"* byte_array - The binary to parse from\n  * position - The position to start parsing from","ref":"ExDicom.Parser.BigEndianParser.html#read_int32/2-parameters"},{"type":"function","title":"Returns - ExDicom.Parser.BigEndianParser.read_int32/2","doc":"* `{:ok, integer}` - The parsed signed 32-bit integer\n  * `{:error, String.t()}` - Error message if parsing fails","ref":"ExDicom.Parser.BigEndianParser.html#read_int32/2-returns"},{"type":"function","title":"Examples - ExDicom.Parser.BigEndianParser.read_int32/2","doc":"iex> BigEndianParser.read_int32(<<0xFF, 0xFF, 0xFF, 0xFE>>, 0)\n    {:ok, -2}","ref":"ExDicom.Parser.BigEndianParser.html#read_int32/2-examples"},{"type":"function","title":"ExDicom.Parser.BigEndianParser.read_uint16/2","doc":"Parses an unsigned 16-bit integer from a big-endian binary.","ref":"ExDicom.Parser.BigEndianParser.html#read_uint16/2"},{"type":"function","title":"Parameters - ExDicom.Parser.BigEndianParser.read_uint16/2","doc":"* byte_array - The binary to parse from\n  * position - The position to start parsing from","ref":"ExDicom.Parser.BigEndianParser.html#read_uint16/2-parameters"},{"type":"function","title":"Returns - ExDicom.Parser.BigEndianParser.read_uint16/2","doc":"* `{:ok, integer}` - The parsed unsigned 16-bit integer\n  * `{:error, String.t()}` - Error message if parsing fails","ref":"ExDicom.Parser.BigEndianParser.html#read_uint16/2-returns"},{"type":"function","title":"Examples - ExDicom.Parser.BigEndianParser.read_uint16/2","doc":"iex> BigEndianParser.read_uint16(<<0x12, 0x34, 0x56>>, 0)\n    {:ok, 0x1234}","ref":"ExDicom.Parser.BigEndianParser.html#read_uint16/2-examples"},{"type":"function","title":"ExDicom.Parser.BigEndianParser.read_uint32/2","doc":"Parses an unsigned 32-bit integer from a big-endian binary.","ref":"ExDicom.Parser.BigEndianParser.html#read_uint32/2"},{"type":"function","title":"Parameters - ExDicom.Parser.BigEndianParser.read_uint32/2","doc":"* byte_array - The binary to parse from\n  * position - The position to start parsing from","ref":"ExDicom.Parser.BigEndianParser.html#read_uint32/2-parameters"},{"type":"function","title":"Returns - ExDicom.Parser.BigEndianParser.read_uint32/2","doc":"* `{:ok, integer}` - The parsed unsigned 32-bit integer\n  * `{:error, String.t()}` - Error message if parsing fails","ref":"ExDicom.Parser.BigEndianParser.html#read_uint32/2-returns"},{"type":"function","title":"Examples - ExDicom.Parser.BigEndianParser.read_uint32/2","doc":"iex> BigEndianParser.read_uint32(<<0x12, 0x34, 0x56, 0x78>>, 0)\n    {:ok, 0x12345678}","ref":"ExDicom.Parser.BigEndianParser.html#read_uint32/2-examples"},{"type":"type","title":"ExDicom.Parser.BigEndianParser.byte_array/0","doc":"A binary string containing bytes to parse","ref":"ExDicom.Parser.BigEndianParser.html#t:byte_array/0"},{"type":"type","title":"ExDicom.Parser.BigEndianParser.position/0","doc":"Position in the binary to start parsing from","ref":"ExDicom.Parser.BigEndianParser.html#t:position/0"},{"type":"module","title":"ExDicom.Parser.DicomDataSet","doc":"Internal helper functions for parsing implicit and explicit DICOM data sets.","ref":"ExDicom.Parser.DicomDataSet.html"},{"type":"function","title":"ExDicom.Parser.DicomDataSet.parse_explicit/4","doc":"Reads an explicit data set.","ref":"ExDicom.Parser.DicomDataSet.html#parse_explicit/4"},{"type":"function","title":"Parameters - ExDicom.Parser.DicomDataSet.parse_explicit/4","doc":"* dataset - The dataset to store elements in\n  * byte_stream - The byte stream to read from\n  * max_position - The maximum position to read up to (optional)\n  * opts - Options map with optional keys:\n    * :until_tag - Stop reading when this tag is encountered","ref":"ExDicom.Parser.DicomDataSet.html#parse_explicit/4-parameters"},{"type":"function","title":"ExDicom.Parser.DicomDataSet.parse_implicit/4","doc":"Reads an implicit data set.","ref":"ExDicom.Parser.DicomDataSet.html#parse_implicit/4"},{"type":"function","title":"Parameters - ExDicom.Parser.DicomDataSet.parse_implicit/4","doc":"* dataset - The dataset to store elements in\n  * byte_stream - The byte stream to read from\n  * max_position - The maximum position to read up to (optional)\n  * opts - Options map with optional keys:\n    * :until_tag - Stop reading when this tag is encountered\n    * :vr_callback - Function to determine VR for private tags","ref":"ExDicom.Parser.DicomDataSet.html#parse_implicit/4-parameters"},{"type":"module","title":"ExDicom.Parser.LittleEndianByteArrayParser","doc":"Internal helper functions for parsing different types from a little-endian byte array","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html"},{"type":"function","title":"ExDicom.Parser.LittleEndianByteArrayParser.read_double/2","doc":"Parses 64-bit float from a little-endian byte array","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_double/2"},{"type":"function","title":"ExDicom.Parser.LittleEndianByteArrayParser.read_float/2","doc":"Parses 32-bit float from a little-endian byte array","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_float/2"},{"type":"function","title":"ExDicom.Parser.LittleEndianByteArrayParser.read_int16/2","doc":"Parses a signed int 16 from a little-endian byte array","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_int16/2"},{"type":"function","title":"ExDicom.Parser.LittleEndianByteArrayParser.read_int32/2","doc":"Parses a signed int 32 from a little-endian byte array","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_int32/2"},{"type":"function","title":"ExDicom.Parser.LittleEndianByteArrayParser.read_uint16/2","doc":"Parses an unsigned int 16 from a little-endian byte array","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_uint16/2"},{"type":"function","title":"Parameters - ExDicom.Parser.LittleEndianByteArrayParser.read_uint16/2","doc":"- byte_array: the byte array to read from\n  - position: the position in the byte array to read from","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_uint16/2-parameters"},{"type":"function","title":"Returns - ExDicom.Parser.LittleEndianByteArrayParser.read_uint16/2","doc":"The parsed unsigned int 16","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_uint16/2-returns"},{"type":"function","title":"Raises - ExDicom.Parser.LittleEndianByteArrayParser.read_uint16/2","doc":"ArgumentError if buffer overread would occur","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_uint16/2-raises"},{"type":"function","title":"ExDicom.Parser.LittleEndianByteArrayParser.read_uint32/2","doc":"Parses an unsigned int 32 from a little-endian byte array","ref":"ExDicom.Parser.LittleEndianByteArrayParser.html#read_uint32/2"},{"type":"module","title":"ExDicom.Reader.FindAndSetUNElementLength","doc":"Internal helper functions for parsing DICOM elements.","ref":"ExDicom.Reader.FindAndSetUNElementLength.html"},{"type":"function","title":"ExDicom.Reader.FindAndSetUNElementLength.find_and_set_un_element_length/2","doc":"Reads from the byte stream until it finds the magic number for the Sequence Delimitation\nItem and then sets the length of the element.","ref":"ExDicom.Reader.FindAndSetUNElementLength.html#find_and_set_un_element_length/2"},{"type":"function","title":"Parameters - ExDicom.Reader.FindAndSetUNElementLength.find_and_set_un_element_length/2","doc":"* byte_stream - The byte stream to read from. Must implement the following functions:\n    * read_uint16/0 - Reads an unsigned 16-bit integer from the stream\n    * read_uint32/0 - Reads an unsigned 32-bit integer from the stream\n    * warnings/1 - Logs warning messages\n    * seek/1 - Moves the stream position by given offset\n    Additionally, must have these fields:\n    * position - Current position in the stream\n    * byte_array - The underlying byte array\n  * element - The DICOM element to update. Must have these fields:\n    * tag - The element's tag\n    * data_offset - Offset to the element's data\n    Length will be set on this element.","ref":"ExDicom.Reader.FindAndSetUNElementLength.html#find_and_set_un_element_length/2-parameters"},{"type":"function","title":"Returns - ExDicom.Reader.FindAndSetUNElementLength.find_and_set_un_element_length/2","doc":"The updated element with its length field set.","ref":"ExDicom.Reader.FindAndSetUNElementLength.html#find_and_set_un_element_length/2-returns"},{"type":"function","title":"Examples - ExDicom.Reader.FindAndSetUNElementLength.find_and_set_un_element_length/2","doc":"iex> byte_stream = MockByteStream.new(...)\n    iex> element = %{tag: \"x00100010\", data_offset: 0}\n    iex> FindAndSetUNElementLength.find_and_set_un_element_length(byte_stream, element)\n    %{tag: \"x00100010\", data_offset: 0, length: 42}","ref":"ExDicom.Reader.FindAndSetUNElementLength.html#find_and_set_un_element_length/2-examples"},{"type":"function","title":"Errors - ExDicom.Reader.FindAndSetUNElementLength.find_and_set_un_element_length/2","doc":"* ArgumentError - If byte_stream is nil or doesn't implement required functions","ref":"ExDicom.Reader.FindAndSetUNElementLength.html#find_and_set_un_element_length/2-errors"},{"type":"module","title":"ExDicom.Reader.FindEndOfEncapsulatedElement","doc":"Internal helper functions for parsing encapsulated DICOM pixel data elements.\nHandles reading and managing fragments of encapsulated pixel data.","ref":"ExDicom.Reader.FindEndOfEncapsulatedElement.html"},{"type":"function","title":"ExDicom.Reader.FindEndOfEncapsulatedElement.find/3","doc":"Reads an encapsulated pixel data element and adds an array of fragments to the element\ncontaining the offset and length of each fragment and any offsets from the basic offset\ntable.","ref":"ExDicom.Reader.FindEndOfEncapsulatedElement.html#find/3"},{"type":"function","title":"Parameters - ExDicom.Reader.FindEndOfEncapsulatedElement.find/3","doc":"* byte_stream - The byte stream to read from\n  * element - The element to add fragment information to\n  * warnings - List to collect any warnings during parsing","ref":"ExDicom.Reader.FindEndOfEncapsulatedElement.html#find/3-parameters"},{"type":"function","title":"Returns - ExDicom.Reader.FindEndOfEncapsulatedElement.find/3","doc":"The modified element with fragment information added","ref":"ExDicom.Reader.FindEndOfEncapsulatedElement.html#find/3-returns"},{"type":"function","title":"Raises - ExDicom.Reader.FindEndOfEncapsulatedElement.find/3","doc":"* RuntimeError if required parameters are missing or if basic offset table is not found","ref":"ExDicom.Reader.FindEndOfEncapsulatedElement.html#find/3-raises"},{"type":"type","title":"ExDicom.Reader.FindEndOfEncapsulatedElement.fragment/0","doc":"Type representing a pixel data fragment","ref":"ExDicom.Reader.FindEndOfEncapsulatedElement.html#t:fragment/0"},{"type":"module","title":"ExDicom.Reader.FindItemDelimitationItem","doc":"Internal helper functions for parsing DICOM elements","ref":"ExDicom.Reader.FindItemDelimitationItem.html"},{"type":"function","title":"ExDicom.Reader.FindItemDelimitationItem.find_item_delimitation_item_and_set_element_length/2","doc":"Reads from the byte stream until it finds the magic numbers for the item delimitation item\nand then sets the length of the element.","ref":"ExDicom.Reader.FindItemDelimitationItem.html#find_item_delimitation_item_and_set_element_length/2"},{"type":"function","title":"Parameters - ExDicom.Reader.FindItemDelimitationItem.find_item_delimitation_item_and_set_element_length/2","doc":"* byte_stream: ByteStream struct\n  * element: Map containing element data with :tag and :data_offset fields","ref":"ExDicom.Reader.FindItemDelimitationItem.html#find_item_delimitation_item_and_set_element_length/2-parameters"},{"type":"function","title":"Returns - ExDicom.Reader.FindItemDelimitationItem.find_item_delimitation_item_and_set_element_length/2","doc":"* `{:ok, element, new_stream}` with updated element length and stream position\n  * `{:error, reason}` if byte_stream is nil or if reading fails","ref":"ExDicom.Reader.FindItemDelimitationItem.html#find_item_delimitation_item_and_set_element_length/2-returns"},{"type":"module","title":"ExDicom.Reader.ReadDicomElement","doc":"Provides functions to read a single DICOM element in either Implicit or Explicit VR format.","ref":"ExDicom.Reader.ReadDicomElement.html"},{"type":"function","title":"ExDicom.Reader.ReadDicomElement.read_dicom_element_explicit/3","doc":"Reads one DICOM element from the byte stream using explicit VR rules.","ref":"ExDicom.Reader.ReadDicomElement.html#read_dicom_element_explicit/3"},{"type":"function","title":"Parameters - ExDicom.Reader.ReadDicomElement.read_dicom_element_explicit/3","doc":"- `byte_stream`: the ByteStream\n- `warnings`: a list of warnings (if you track them separately from the stream)\n- `until_tag`: optional tag that, if matched, stops reading","ref":"ExDicom.Reader.ReadDicomElement.html#read_dicom_element_explicit/3-parameters"},{"type":"function","title":"Return Value - ExDicom.Reader.ReadDicomElement.read_dicom_element_explicit/3","doc":"`{:ok, element, updated_stream, updated_warnings}` or `{:error, reason}`","ref":"ExDicom.Reader.ReadDicomElement.html#read_dicom_element_explicit/3-return-value"},{"type":"function","title":"ExDicom.Reader.ReadDicomElement.read_dicom_element_implicit/3","doc":"Reads one DICOM element from the byte stream using implicit VR rules.","ref":"ExDicom.Reader.ReadDicomElement.html#read_dicom_element_implicit/3"},{"type":"function","title":"Parameters - ExDicom.Reader.ReadDicomElement.read_dicom_element_implicit/3","doc":"- `byte_stream`: the ByteStream\n- `until_tag`: optional tag; if we encounter it, we immediately return the element\n- `vr_callback`: (optional) a function that returns a VR given a tag (for private dictionary lookups, etc.)","ref":"ExDicom.Reader.ReadDicomElement.html#read_dicom_element_implicit/3-parameters"},{"type":"function","title":"Return Value - ExDicom.Reader.ReadDicomElement.read_dicom_element_implicit/3","doc":"Typically returns `{:ok, element, updated_stream, warnings}` or `{:error, reason}`.","ref":"ExDicom.Reader.ReadDicomElement.html#read_dicom_element_implicit/3-return-value"},{"type":"module","title":"ExDicom.Reader.ReadEncapsulatedImageFrame","doc":"Functionality for extracting encapsulated image frames from DICOM data.","ref":"ExDicom.Reader.ReadEncapsulatedImageFrame.html"},{"type":"function","title":"ExDicom.Reader.ReadEncapsulatedImageFrame.read_frame/4","doc":"Returns the pixel data for the specified frame in an encapsulated pixel data element\nthat has a non-empty basic offset table.","ref":"ExDicom.Reader.ReadEncapsulatedImageFrame.html#read_frame/4"},{"type":"function","title":"Parameters - ExDicom.Reader.ReadEncapsulatedImageFrame.read_frame/4","doc":"* dataset - The dataset containing the encapsulated pixel data\n  * pixel_data_element - The pixel data element (x7fe00010) to extract from\n  * frame_index - Zero based frame index\n  * opts - Optional parameters\n    * :basic_offset_table - Optional array of starting offsets for frames\n    * :fragments - Optional array of fragment descriptors","ref":"ExDicom.Reader.ReadEncapsulatedImageFrame.html#read_frame/4-parameters"},{"type":"function","title":"Returns - ExDicom.Reader.ReadEncapsulatedImageFrame.read_frame/4","doc":"* `{:ok, binary}` - The extracted frame data\n  * `{:error, reason}` - If extraction fails","ref":"ExDicom.Reader.ReadEncapsulatedImageFrame.html#read_frame/4-returns"},{"type":"module","title":"ExDicom.Reader.ReadEncapsulatedPixelData","doc":"Functionality for extracting encapsulated pixel data from DICOM fragments.","ref":"ExDicom.Reader.ReadEncapsulatedPixelData.html"},{"type":"function","title":"ExDicom.Reader.ReadEncapsulatedPixelData.read_from_fragments/4","doc":"Returns the encapsulated pixel data from the specified fragments.","ref":"ExDicom.Reader.ReadEncapsulatedPixelData.html#read_from_fragments/4"},{"type":"function","title":"Parameters - ExDicom.Reader.ReadEncapsulatedPixelData.read_from_fragments/4","doc":"* dataset - The dataset containing the encapsulated pixel data\n  * pixel_data_element - The pixel data element (x7fe00010) to extract from\n  * start_fragment_index - Zero based index of the first fragment\n  * opts - Optional parameters\n    * :num_fragments - Number of fragments to extract (default: 1)\n    * :fragments - Optional array of fragment descriptors (default: pixel_data_element.fragments)","ref":"ExDicom.Reader.ReadEncapsulatedPixelData.html#read_from_fragments/4-parameters"},{"type":"function","title":"Returns - ExDicom.Reader.ReadEncapsulatedPixelData.read_from_fragments/4","doc":"* `{:ok, binary}` - The extracted pixel data\n  * `{:error, reason}` - If extraction fails","ref":"ExDicom.Reader.ReadEncapsulatedPixelData.html#read_from_fragments/4-returns"},{"type":"module","title":"ExDicom.Reader.ReadPart10Header","doc":"Parses a DICOM P10 byte array and returns a meta-header DataSet.","ref":"ExDicom.Reader.ReadPart10Header.html"},{"type":"function","title":"ExDicom.Reader.ReadPart10Header.read_part10_header/2","doc":"Reads the Part 10 header from the given `byte_array`.\n\nOptions can include:\n- `:transfer_syntax_uid`\n\nReturns `{:ok, meta_header_map_or_struct}` or `{:error, reason}`.\n\nThe `meta_header_map_or_struct` might contain fields:\n- `:elements` => a map of parsed elements\n- `:warnings` => a list of warnings\n- `:position` => the position in the byte stream","ref":"ExDicom.Reader.ReadPart10Header.html#read_part10_header/2"},{"type":"module","title":"ExDicom.Reader.ReadSequence","doc":"Provides functions to read DICOM sequence items in both explicit and implicit VR.","ref":"ExDicom.Reader.ReadSequence.html"},{"type":"function","title":"ExDicom.Reader.ReadSequence.read_sequence_items_explicit/3","doc":"Reads sequence items for an element in an **explicit** VR byte stream.\n\nReturns:\n- `{:ok, updated_element, updated_stream, updated_warnings}` on success\n- `{:error, reason}` on failure","ref":"ExDicom.Reader.ReadSequence.html#read_sequence_items_explicit/3"},{"type":"function","title":"ExDicom.Reader.ReadSequence.read_sequence_items_implicit/3","doc":"Reads sequence items for an element in an **implicit** VR byte stream.\n\nReturns:\n- `{:ok, updated_element, updated_stream, updated_warnings}` on success\n- `{:error, reason}` on failure","ref":"ExDicom.Reader.ReadSequence.html#read_sequence_items_implicit/3"},{"type":"module","title":"ExDicom.Reader.ReadSequenceItem","doc":"Internal helper functions for parsing DICOM elements","ref":"ExDicom.Reader.ReadSequenceItem.html"},{"type":"function","title":"ExDicom.Reader.ReadSequenceItem.read_sequence_item/1","doc":"Reads the tag and length of a sequence item.\n\nReturns a tuple of {:ok, element, byte_stream} where:\n  * element is a map with the following keys:\n    * :tag - string for the tag of this element in the format xggggeeee\n    * :length - the number of bytes in this item or 4294967295 if undefined\n    * :data_offset - the offset into the byteStream of the data for this item\n  * byte_stream is the remaining byte stream after reading","ref":"ExDicom.Reader.ReadSequenceItem.html#read_sequence_item/1"},{"type":"function","title":"Parameters - ExDicom.Reader.ReadSequenceItem.read_sequence_item/1","doc":"* byte_stream - The byte stream to read from. Must implement the ByteStream protocol","ref":"ExDicom.Reader.ReadSequenceItem.html#read_sequence_item/1-parameters"},{"type":"function","title":"Returns - ExDicom.Reader.ReadSequenceItem.read_sequence_item/1","doc":"* `{:ok, element, byte_stream}` - Successfully read sequence item\n  * raises ArgumentError - If byte_stream is nil\n  * raises RuntimeError - If the sequence item tag (FFFE,E000) is not found","ref":"ExDicom.Reader.ReadSequenceItem.html#read_sequence_item/1-returns"},{"type":"module","title":"ExDicom.Reader.ReadTag","doc":"Provides a function to read a DICOM tag (group + element) from a ByteStream.\n\nCorresponds to the JavaScript function:\n\n    export default function readTag(byteStream) {\n      if (byteStream === undefined) {\n        throw 'dicomParser.readTag: missing required parameter 'byteStream'';\n      }\n\n      const groupNumber = byteStream.readUint16() * 256 * 256;\n      const elementNumber = byteStream.readUint16();\n      const tag = `x${(\"00000000\" + (groupNumber + elementNumber).toString(16)).substr(-8)}`;\n\n      return tag;\n    }","ref":"ExDicom.Reader.ReadTag.html"},{"type":"function","title":"ExDicom.Reader.ReadTag.read_tag/1","doc":"Reads a tag (group number and element number) from a ByteStream, returning\nthe tag in the format `xggggeeee` where `gggg` and `eeee` are lowercase hex.","ref":"ExDicom.Reader.ReadTag.html#read_tag/1"},{"type":"function","title":"Examples - ExDicom.Reader.ReadTag.read_tag/1","doc":"iex> {:ok, tag, updated_stream} = ExDicom.ReadTag.read_tag(stream)\n    iex> tag\n    \"x00080020\"\n\nReturns:\n  * `{:ok, tag_string, updated_stream}` on success\n  * `{:error, reason}` if there's a problem (e.g. missing stream)","ref":"ExDicom.Reader.ReadTag.html#read_tag/1-examples"},{"type":"module","title":"ExDicom.SharedCopy","doc":"Module containing helper functions for working with binary data in DICOM parsing.","ref":"ExDicom.SharedCopy.html"},{"type":"function","title":"ExDicom.SharedCopy.copy/3","doc":"Creates a binary slice of the input binary data.","ref":"ExDicom.SharedCopy.html#copy/3"},{"type":"function","title":"Parameters - ExDicom.SharedCopy.copy/3","doc":"* binary - The input binary data\n  * byte_offset - Offset into the binary to start the slice\n  * length - Number of bytes to include in the slice","ref":"ExDicom.SharedCopy.html#copy/3-parameters"},{"type":"function","title":"Returns - ExDicom.SharedCopy.copy/3","doc":"* `{:ok, binary}` - A binary slice sharing the same underlying memory\n  * `{:error, String.t()}` - Error message if the input is invalid","ref":"ExDicom.SharedCopy.html#copy/3-returns"},{"type":"function","title":"Examples - ExDicom.SharedCopy.copy/3","doc":"iex> DicomParser.copy(<<1, 2, 3, 4>>, 1, 2)\n    {:ok, <<2, 3>>}","ref":"ExDicom.SharedCopy.html#copy/3-examples"},{"type":"module","title":"ExDicom.Util.DAParser","doc":"Parses DA formatted date strings into maps with date components.\nThe DA format expects strings in the format YYYYMMDD where:\n- YYYY represents the year\n- MM represents the month (01-12)\n- DD represents the day (01-31, depending on month)","ref":"ExDicom.Util.DAParser.html"},{"type":"function","title":"ExDicom.Util.DAParser.days_in_month/2","doc":"Returns the number of days in the given month for a specific year.","ref":"ExDicom.Util.DAParser.html#days_in_month/2"},{"type":"function","title":"Examples - ExDicom.Util.DAParser.days_in_month/2","doc":"iex> DAParser.days_in_month(2, 2024)\n    29\n\n    iex> DAParser.days_in_month(2, 2023)\n    28\n\n    iex> DAParser.days_in_month(4, 2024)\n    30","ref":"ExDicom.Util.DAParser.html#days_in_month/2-examples"},{"type":"function","title":"ExDicom.Util.DAParser.parse/2","doc":"Parses a DA formatted string into a map with date components.","ref":"ExDicom.Util.DAParser.html#parse/2"},{"type":"function","title":"Parameters - ExDicom.Util.DAParser.parse/2","doc":"* date - String in DA format (YYYYMMDD)\n  * validate - Boolean indicating whether to validate the date components","ref":"ExDicom.Util.DAParser.html#parse/2-parameters"},{"type":"function","title":"Returns - ExDicom.Util.DAParser.parse/2","doc":"* `{:ok, map}` with date components if valid\n  * `{:error, string}` with error message if invalid and validate is true\n  * `{:ok, nil}` if input is invalid and validate is false","ref":"ExDicom.Util.DAParser.html#parse/2-returns"},{"type":"function","title":"Examples - ExDicom.Util.DAParser.parse/2","doc":"iex> DAParser.parse(\"20240131\")\n    {:ok, %{year: 2024, month: 1, day: 31}}\n\n    iex> DAParser.parse(\"20240229\")\n    {:ok, %{year: 2024, month: 2, day: 29}}\n\n    iex> DAParser.parse(\"20230229\", true)\n    {:error, \"invalid DA '20230229'\"}","ref":"ExDicom.Util.DAParser.html#parse/2-examples"},{"type":"type","title":"ExDicom.Util.DAParser.date_components/0","doc":"","ref":"ExDicom.Util.DAParser.html#t:date_components/0"},{"type":"module","title":"ExDicom.Util.Misc","doc":"Utility functions for DICOM parsing and data handling.","ref":"ExDicom.Util.Misc.html"},{"type":"function","title":"ExDicom.Util.Misc.parse_pn/1","doc":"Parses a PN (Person Name) formatted string into a map with standardized name components.","ref":"ExDicom.Util.Misc.html#parse_pn/1"},{"type":"function","title":"Parameters - ExDicom.Util.Misc.parse_pn/1","doc":"* person_name - A string in the PN VR format (components separated by ^)","ref":"ExDicom.Util.Misc.html#parse_pn/1-parameters"},{"type":"function","title":"Returns - ExDicom.Util.Misc.parse_pn/1","doc":"* A map with :family_name, :given_name, :middle_name, :prefix, and :suffix keys\n  * `nil` if input is nil","ref":"ExDicom.Util.Misc.html#parse_pn/1-returns"},{"type":"function","title":"Examples - ExDicom.Util.Misc.parse_pn/1","doc":"iex> ExDicom.Util.parse_pn(\"Smith^John^A^Dr^Jr\")\n    %{\n      family_name: \"Smith\",\n      given_name: \"John\",\n      middle_name: \"A\",\n      prefix: \"Dr\",\n      suffix: \"Jr\"\n    }\n\n    iex> ExDicom.Util.parse_pn(nil)\n    nil","ref":"ExDicom.Util.Misc.html#parse_pn/1-examples"},{"type":"function","title":"ExDicom.Util.Misc.private_tag?/1","doc":"Tests if a given tag in the format xggggeeee is a private tag.\nPrivate tags are identified by having an odd group number.","ref":"ExDicom.Util.Misc.html#private_tag?/1"},{"type":"function","title":"Parameters - ExDicom.Util.Misc.private_tag?/1","doc":"* tag - The DICOM tag in format xggggeeee","ref":"ExDicom.Util.Misc.html#private_tag?/1-parameters"},{"type":"function","title":"Returns - ExDicom.Util.Misc.private_tag?/1","doc":"* `true` if the tag is private\n  * `false` if the tag is not private","ref":"ExDicom.Util.Misc.html#private_tag?/1-returns"},{"type":"function","title":"Raises - ExDicom.Util.Misc.private_tag?/1","doc":"* RuntimeError if the fourth character of the tag cannot be parsed as hex","ref":"ExDicom.Util.Misc.html#private_tag?/1-raises"},{"type":"function","title":"Examples - ExDicom.Util.Misc.private_tag?/1","doc":"iex> ExDicom.Util.private_tag?(\"x00090010\")\n    true\n\n    iex> ExDicom.Util.private_tag?(\"x00080010\")\n    false","ref":"ExDicom.Util.Misc.html#private_tag?/1-examples"},{"type":"function","title":"ExDicom.Util.Misc.string_vr?/1","doc":"Tests if the given VR (Value Representation) is a string type.","ref":"ExDicom.Util.Misc.html#string_vr?/1"},{"type":"function","title":"Parameters - ExDicom.Util.Misc.string_vr?/1","doc":"* vr - The VR code to test","ref":"ExDicom.Util.Misc.html#string_vr?/1-parameters"},{"type":"function","title":"Returns - ExDicom.Util.Misc.string_vr?/1","doc":"* `true` if string type\n  * `false` if not string type\n  * `nil` if unknown VR or UN type","ref":"ExDicom.Util.Misc.html#string_vr?/1-returns"},{"type":"function","title":"Examples - ExDicom.Util.Misc.string_vr?/1","doc":"iex> ExDicom.Util.string_vr?(\"PN\")\n    true\n\n    iex> ExDicom.Util.string_vr?(\"UN\")\n    nil","ref":"ExDicom.Util.Misc.html#string_vr?/1-examples"},{"type":"type","title":"ExDicom.Util.Misc.person_name/0","doc":"Type representing a parsed person name with standard DICOM components.","ref":"ExDicom.Util.Misc.html#t:person_name/0"},{"type":"module","title":"ExDicom.Util.TMParser","doc":"Parses TM formatted strings into a map with time components.\nThe TM format expects strings in the format HHMMSS.FFFFFF where:\n- HH represents hours (00-23)\n- MM represents minutes (00-59)\n- SS represents seconds (00-59)\n- FFFFFF represents fractional seconds (000000-999999)","ref":"ExDicom.Util.TMParser.html"},{"type":"function","title":"ExDicom.Util.TMParser.parse/2","doc":"Parses a TM formatted string into a map with time components.","ref":"ExDicom.Util.TMParser.html#parse/2"},{"type":"function","title":"Parameters - ExDicom.Util.TMParser.parse/2","doc":"* time - String in TM VR format\n  * validate - Boolean indicating whether to validate the time components","ref":"ExDicom.Util.TMParser.html#parse/2-parameters"},{"type":"function","title":"Returns - ExDicom.Util.TMParser.parse/2","doc":"* `{:ok, map}` with time components if valid\n  * `{:error, string}` with error message if invalid and validate is true\n  * `{:ok, nil}` if input is invalid and validate is false","ref":"ExDicom.Util.TMParser.html#parse/2-returns"},{"type":"function","title":"Examples - ExDicom.Util.TMParser.parse/2","doc":"iex> TMParser.parse(\"14\")\n    {:ok, %{hours: 14, minutes: nil, seconds: nil, fractional_seconds: nil}}\n\n    iex> TMParser.parse(\"1430\")\n    {:ok, %{hours: 14, minutes: 30, seconds: nil, fractional_seconds: nil}}\n\n    iex> TMParser.parse(\"143022.123\")\n    {:ok, %{hours: 14, minutes: 30, seconds: 22, fractional_seconds: 123000}}\n\n    iex> TMParser.parse(\"24\", true)\n    {:error, \"invalid TM '24'\"}","ref":"ExDicom.Util.TMParser.html#parse/2-examples"},{"type":"type","title":"ExDicom.Util.TMParser.time_components/0","doc":"","ref":"ExDicom.Util.TMParser.html#t:time_components/0"},{"type":"extras","title":"ExDicom","doc":"# ExDicom\n\nExDicom is an Elixir library for parsing DICOM (Digital Imaging and Communications in Medicine) files. It is basically a rough Elixir port of the [Cornerstone DICOM Parser](https://github.com/cornerstonejs/dicomParser) JavaScript library.","ref":"readme.html"},{"type":"extras","title":"Features - ExDicom","doc":"- Parse DICOM files with support for various transfer syntaxes\n- Handle both explicit and implicit VR (Value Representation)\n- Support for deflated transfer syntax\n- Extract DICOM elements and attributes\n- Read common DICOM data types (strings, integers, etc.)","ref":"readme.html#features"},{"type":"extras","title":"Installation - ExDicom","doc":"Add `ex_dicom` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n[\n  {:ex_dicom, \"~> 0.1.0\"}\n]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - ExDicom","doc":"Basic usage to parse a DICOM file:\n\n```elixir\n# Parse a DICOM file\n{:ok, dataset} = ExDicom.parse_file(\"path/to/dicom/file.dcm\")\n\n# Access DICOM elements\npatient_name = ExDicom.DataSet.string(dataset, \"x00100010\")\nmodality = ExDicom.DataSet.string(dataset, \"x00080060\")\nrows = ExDicom.DataSet.uint16(dataset, \"x00280010\")\ncolumns = ExDicom.DataSet.uint16(dataset, \"x00280011\")\n```","ref":"readme.html#usage"},{"type":"extras","title":"Credits - ExDicom","doc":"This library is an Elixir port of the [Cornerstone DICOM Parser](https://github.com/cornerstonejs/dicomParser) JavaScript library. Many thanks to the core team & all the contributors over there.","ref":"readme.html#credits"},{"type":"extras","title":"License - ExDicom","doc":"This project is licensed under the [MIT License](LICENSE). The original Cornerstone DICOM Parser is also MIT licensed.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}